HomeMy WebLinkAboutReso 2026-3971RESOLUTION NO. 2026 -
A RESOLUTION OF THE CITY COMMISSION OF THE CITY OF SUNNY ISLES BEACH,
FLORIDA, APPROVING A FIRST AMENDMENT TO THE AGREEMENT WITH NEON
SIGNS SOLUTIONS, INC. FOR THE REMOVAL, FABRICATION, AND INSTALLATION
OF MONUMENT SIGNS THROUGHOUT THE CITY, IN AN AMOUNT NOT TO
EXCEED FIFTEEN THOUSAND DOLLARS AND NO CENTS ($15,000.00), ATTACHED
HERETO AS EXHIBIT "A"; AUTHORIZING THE MAYOR TO EXECUTE SAID
AMENDMENT; AUTHORIZING THE CITY MANAGER TO DO ALL THINGS
NECESSARY TO EFFECTUATE THIS RESOLUTION; PROVIDING FOR AN EFFECTIVE
DATE.
WHEREAS, on February 20, 2025, via Resolution No. 2025-3799, the City Commission of
the City of Sunny Isles Beach (the "City") approved an Agreement with Neon Signs Solutions, Inc.
(the "Contractor") to remove, fabricate, and install new monument signs (the "Services"), in an
amount not to exceed $950,000.00; and
WHEREAS, the Contractor is responsible for work associated with three (3) monuments
located within Florida Department of Transportation ("FDOT") Rights -of -Way, including the
William Lehman Causeway monument and the north and south Collins Avenue welcome signs;
and
WHEREAS, FDOT requires additional liability insurance coverage as a condition of
permitting the aforementioned monuments within its Rights -of -Way ("Additional Insurance"),
requiring additional funds; and
WHEREAS, the Contractor has requested a time extension of six (6) months, through
August 23, 2027, to allow sufficient time for completion of the Services ("Time Extension"); and
WHEREAS, the City wishes to approve a First Amendment to the Agreement with the
Contractor approving the Time Extension and the additional funds in an amount not to exceed
Fifteen Thousand Dollars and No Cents ($15,000.00), to cover the costs of the Additional
Insurance, attached hereto as Exhibit "A".
NOW, THEREFORE, BE IT RESOLVED BY THE CITY COMMISSION OF THE CITY OF SUNNY.
ISLES BEACH, FLORIDA, AS FOLLOWS:
Section 1. Approval of First Amendment. The City Commission hereby approves a First
Amendment to the Agreement with the Contractor approving the Time Extension and the
additional funds in an amount not to exceed Fifteen Thousand Dollars and No Cents
($15,000.00), to cover the costs of the Additional Insurance, attached hereto as Exhibit "A".
Section 2. Authorization of Mayor. The Mayor is hereby authorized to execute said
Amendment.
Section 3. Authorization of City Manager. The City Manager is hereby authorized to do all
things necessary to effectuate this Resolution.
R2026 First Amend w Neon Signs for Monument Signs.doc Page 1 of 2
Section 4. Effective Date. This Resolution shall become effective upon adoption.
PASSED AND ADOPTED this 19th day o ebruary, 2025.
Larisa Svechin, Mayor
ATTES WAPPROVED AS TO FORM
AND LEGAL SUFFICIENCY:
Mau ri io B tancu , CIVIC, City Clerk A in E. Boileau, P.A., for Nabors, Giblin &
Nickerson, City Attorney
c �
Moved by. Seconded by: uls&oI.J -�
Vote:
Mayor Svechin
(Yes)
(No)
Vice Mayor Viscarra
(Yes)
(No)
Commissioner Joseph
(Yes)
(No)
Commissioner Lama
(Yes)
(No)
Commissioner Stuyvesant
(Yes)
(No)
@BCL@AC164252 Page 2 of 2 718
FIRST AMENDMENT TO THE AGREEMENT BETWEEN
THE CITY OF SUNNY ISLES BEACH AND
F 'FL00.
r : NEON SIGN SOLUTIONS, INC.
o SUH ANc
CONTRACT NO.2025-8913
THIS FIRST AMENDMENT TO THE AGREEMENT between the CITY OF SUNNY
ISLES BEACH (hereinafter "City") and NEON SIGN SOLUTIONS, INC., a Florida
corporation, whose Federal Employer Identification (FEI) Number is 65-1002696 (hereinafter
"Contractor"), executed this 2rday of February 2026, is made a part of the original Agreement
between the City and Contractor, dated February 24, 2025 (hereinafter "Agreement"), attached
hereto as Exhibit "A." The City and Contractor hereby agree as follows:
1. TERM. City and Contractor wish to amend Section 4 of the Agreement, entitled "Term,"
as follows:
Subject to the provisions relating to the termination of this Agreement as set forth
hereunder, the term of this Agreement shall commence upon full exee ien of —
Agy-eeme on February 24, 2025, and shall terminate tive (2) years then -ea fte on August
23, 2027.
2. ADDITIONAL COMPENSATION. City and Contractor wish to amend Section 5 of the
Agreement, entitled "Compensation," as follows:
The City shall pay Contractor for Services performed under this Agreement, in the amount
of Nine d T-hi y Nine Tl,..,,s..,-..7 Seye«. u,,,..a,-oa TNine Hundred Fifty -One
Thousand One Hundred Eigh -Three Dollars and No Twenty -Five Cents ($939,�00
$951,183,25), plus Tor Thousand Twe u„rdr-ed Ninety Right Thirteen Thousand Eight
Hundred Sixteen Dollars and Ne Seventy -Five Cents ($10,298 nn $13,816.75) for
contingency, if necessary, resulting in a total not -to -exceed amount of Nine H+m roa Fifty
Thousan Nine Hundred Sixty Five Thousand Dollars and No Cents (�950,000.00
$965,000.00). Payment to Contractor for all charges and tasks under this Agreement shall
be in accordance with the Contract Documents and the schedule of charges therein for the
term of the Agreement, under the following conditions:
B. Payment Schedule. Payment to Contractor of the sum set forth herein shall be
allocated based upon the following:
g
„Design/Ins .
Print
50%o Instl '
FF
Total
x
Leahman Causeway1
$23,441.63
Q'� �
$11,960.38
$35,881.13
—
$59,801.89
$1 9�9
$131,085.03
Government Center x 1
$5,534.84
Q "�68
$16,604.52
$27,674.20
$55,348.40
$5,534.84
Median Welcome x 2
$6,460.79
Q'''�9
$19,382.38
$32,303.98
$64,607.94
.
$6,460.79
Neighborhood & Park x
14
$62,624.73
Q' `' 5-249.-^�6-
$187,874.18
$313,123.64
$626,247.28
$62,624.73
Sunny Isles Blvd. x 1
$7,389.46
Q' ^,�I— 77S-Q
$22,168.38
$36,947.30
$73,894.60
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone(305) 949-311..3 Fax
3. OTHER TERMS AND CONDITIONS REMAIN IN EFFECT. Except as specifically
modified herein, all terms and conditions of the original Agreement between the parties, dated
February 24, 2025, shall remain in full force and effect.
4. CONFLICTING PROVISIONS. The terms, statements, requirements, or provisions
contained in this First Amendment shall prevail and be given superior effect and priority over any
conflicting or inconsistent terms, statements, requirements, or provisions contained in any other
document or attachment, including but not limited to Exhibit "A."
IN WITNESS WHEREOF, the parties hereto have executed this First Amendment as of
the date mentioned above.
NEON SIGN SOLUTIONS, INC.
BY:
Jorge arraga, President
STATE OF FLORIDA:
COUNTY OF MIAMI-DADS:
The foregoing instrument was acknowledged before me by means of physical presence or ❑
online notarization, this 2 f day of February 2026 by Jorge Idarra al, as Pr 'dent o Neon Sign
tm
Solutions, Inc,
(SEAL) Notary 1' f Florida
SANDRAMMURTON (SIp!Gre4 Notary Public)
ti=.
g . Notary Public State of Florida
A
��p commission # HH 715801 ,
,.��. My Comm. Expires Sep 1, 2029 4, y.z � Axt
Bonded throush National Notary Assn. (Print, Type, Or Stamp
Commissioned Name of Notary
'Public)
Personally Known x or Produced Identification
Type of Identification Produced:.
NEON SIGN SOLUTIONS, INC. — FIRST AMENDMENT Page 2 of
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
A
CITY OF NNY SLES BEACH
BY:
Larisa Svechin, Mayor
APPROVED AS TO FORM AND
LEGAL SUFFICIENCY
BY: 74 61ii4,
A ain E. Boileau, for Nabors, Giblin
& Nickerson, P.A., City Attorney
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
EXHIBIT A
j AGREEMENT BETWEEN THE CITY OF SUNNY ISLES
BEACH AND NEON SIGN SOLUTIONS, INC.
CONTRACT NO.2025-8913
THIS CONTRACTUAL AGREEMENT (hereinafter referred to as the "Agreement") is
made in duplicate, this -oday of February, 2025, by and between the CITY OF SUNNY ISLES
BEACH, Florida, (hereinafter referred to as "City"), and NEON SIGN SOLUTIONS, INC., a
Florida corporation whose Federal Employer Identification (FEI) No. is 65-1002696 (hereinafter
referred to as "Contractor").
RECITALS
WHEREAS, the City is in need of a Contractor for the removal, fabrication, and
installation of monument signs throughout the City, as more particularly described in
Attachment "A," a copy of which is attached hereto and incorporated herein by reference
(hereinafter "Services"); and
WHEREAS, Miami -Dade County issued Request to Qualify ("RTQ") No. RTQ-00918,
entitled "Signs and Banners: Purchase, Installation & Removal," for pre -qualified vendors,
appended hereto as Attachment `B" and on or about May 1, 2019, Miami -Dade County selected
various contractors, including Contractor, as pre -qualified vendors, for the purchase, installation,
and/or removal of signs and banners, from May 1, 2019 through July 31, 2029, appended hereto
as Attachment "C;" and
WHEREAS, Contractor is a certified and insured company with the necessary experience
to provide the desired Services; and
WHEREAS, the City desires to enter into an agreement with Contractor, using Miami -
Dade County's solicitation information, and the resulting contract thereto, to provide the Services
as described herein, and subject to the terms and conditions contained herein; and
WHEREAS, pursuant to the City's procurement code provisions, purchases made under
state, county, or other governmental contracts, or competitive bids with other entities are exempt
from the City's competitive bidding procedures; and
WHEREAS, the City desires to enter into this Agreement with Contractor to provide the
Services for Nine Hundred Thirty Nine Thousand Seven Hundred Two Dollars and No Cents
($939,702.00), plus Ten Thousand Two Hundred Ninety -Eight Dollars and No Cents ($10,298.00)
for contingency, if necessary, resulting in a total not -to -exceed amount of Nine Hundred Fifty
Thousand Dollars and No Cents ($950,000.00);
NOW THEREFORE, in consideration of the foregoing and for the mutual covenants,
representations, and warranties, and other good and valuable consideration, the receipt and
sufficiency of which is hereby acknowledged, the Parties agree as follows:
TERMS
1. RECITALS. The Recitals set forth above are hereby incorporated into this Agreement
and made a part hereof for reference.
NEON SIGN SOLUTIONS, INC.
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
2. THE CONTRACT DOCUMENTS. The Contract Documents consist of this Agreement,
as well as the terms and conditions of RTQ No. RTQ-00918, entitled "Signs and Banners:
Purchase, Installation & Removal," and the resulting contract, which are specifically incorporated
herein and made a part hereof respectively as Attachments `B" and "C" (hereinafter referred to
collectively as "Contract Documents"). In the event of any conflict between or among the contract
documents or any ambiguity or missing specifications or instruction, the following priority is
established:
A. First, this Agreement Between the City of Sunny Isles Beach and Neon Sign Solutions,
Inc. — Contract No. 2025-8913.
B. Second, Contractor's Estimate, appended hereto as Attachment "A."
C. Third, the terms and conditions of RTQ No. RTQ-00918 entitled "Signs and Banners:
Purchase, Installation & Removal."
D. Fourth, Contractor's contract with Miami -Dade County.
3. SERVICES. Contractor shall provide Services to the City pursuant to the terms and
conditions set forth in the Contract Documents, to specifically include, but not limited to,
removing, fabricating, and installing monument signs throughout the City, as more
particularly described in Attachment "A." The Contractor shall furnish all labor, equipment,
and materials necessary to furnish the Services in accordance with the specifications in the
Contract Documents. The Services shall be performed by Contractor to the full satisfaction of the
City. Contractor agrees to furnish all labor and material in a good and workmanlike and
professional manner to perform Services. Contractor agrees to have a qualified representative to
audit and inspect the Services provided on a regular basis to ensure all Services are being
performed in accordance with the City's needs and pursuant to the terms of this Agreement, and
shall report to the City accordingly. Contractor agrees to immediately inform the City via
telephone and in writing of any problems that could cause damage to the City's property,
improvements, and persons. Contractor will require its employees to perform their work in a
manner consistent with the type and scope of work to be performed. In the event that the
Contractor fails to complete the Services pursuant to the terms of this contract and City must
undertake the completion of performance of Services, Contractor agrees to indemnify the City or
all costs incurred with respect to the completion of those Services and any damages the City may
suffer as a result of Contractor's failure to perform the Services.
4. TERM. Subject to the provisions relating to the termination of this Agreement as set
forth hereunder, the term of this Agreement shall commence upon full execution of the Agreement,
and shall terminate two (2) years thereafter.
The terms of Section 8, entitled "Warranty of Goods and Services," Section 9, entitled "Defective
Work," Section 12, entitled "Indemnification and Waiver of Liability," and Section 19, entitled
"Compliance with Law," shall survive termination of this Agreement.
5. COMPENSATION. The City shall pay Contractor for Services performed under this
Agreement, in the amount of Nine Hundred Thirty -Nine Thousand Seven Hundred Two Dollars
and No Cents ($939,702.00), plus Ten Thousand Two Hundred Ninety -Eight Dollars and No Cents
($10,298.00) for contingency, if necessary, resulting in a total not -to -exceed amount of Nine
Hundred Fifty Thousand Dollars and No Cents ($950,000.00). Payment to Contractor for all
NEON SIGN SOLUTIONS, INC.
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
charges and tasks under this Agreement shall be in accordance with the Contract Documents and
the schedule of charges therein for the term of the Agreement, under the following conditions:
A. Disbursements. There are no reimbursable expenses associated with this contract
except for expenses approved by the City Manager or his designee.
B. Payment Schedule. Payment to Contractor of the sum set forth herein shall be
allocated based upon the following:
$35,881.19
$59,801.98
$119,603.78
$16,604.52
$27,674.20
$55,348.40
$19,382.38
$32,303.97
$64,607.94
$187,874.18
$313,123.64
$626,247.28
$22,168.38
Invoices received from the Contractor pursuant to this Agreement will be reviewed
by the initiating City Department. Payment will be made by the City in accordance
with the Contract Documents and in accordance with Florida's Prompt Payment
Act. If services have been rendered in conformity with the Agreement, the invoice
will be sent to the Finance Department for payment. Invoices must reference the
contract number assigned hereto.
C. Availability of Funds. The City's performance and obligation to pay under this
Agreement is contingent upon an annual appropriation for its purpose by the City
Commission. If the City should not appropriate or otherwise make available funds
sufficient to purchase the Services procured pursuant to this Agreement, the City
may unilaterally terminate any and all contractual or other obligations herein
without any further liability or penalty upon twenty (20) days' notice to Contractor.
D. Final Invoice. In order for both parties herein to close their books and records, the
Contractor will clearly state "final invoice" on the Contractor's final/last billing to
the City. This certifies that all services have been properly performed and all
charges and costs have been invoiced to the City. Since this account will thereupon
be closed, any other additional charges, if not properly included on this final
invoice, are waived by the Contractor.
Contractor shall make no other charges to the City for supplies, labor, taxes, licenses, permits,
overhead or any other expenses or costs unless any such expense or cost is incurred by Contractor
with the prior written approval of the City. If the City disputes any charges on the invoices, it may
make payment of the uncontested amounts and withhold payment on the contested amounts until
they are resolved by agreement with Contractor. Contractor shall not pledge the City's credit or
make it a guarantor of payment or surety for any contract, debt, obligation, judgment, lien, or any
form of indebtedness. The Contractor further warrants and represents that it has no obligation or
indebtedness that would impair its ability to fulfill the terms of this Agreement.
NEON SIGN SOLUTIONS, INC.
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
6. INDEPENDENT CONTRACTOR RELATIONSHIP. The Contractor is an
independent Contractor and shall be treated as such for all purposes. Nothing contained in this
Agreement or any action of the parties shall be construed to constitute or to render the Contractor
an employee, partner, agent, shareholder, officer or in any other capacity other than as an
independent Contractor other than those obligations which have been or shall have been
undertaken by the City. Contractor shall be responsible for any and all of its own expenses in
performing its duties as contemplated under this Agreement. The City shall not be responsible for
any expense incurred by the Contractor. The City shall have no duty to withhold any Federal
income taxes or pay Social Security services and that such obligations shall be that of the
Contractor, other than those set forth in this Agreement. Contractor shall furnish its own
transportation, office and other supplies as it determines necessary in carrying out its duties under
this Agreement.
7. INSURANCE. Contractor shall, at its sole cost and expense, during the period of any
work being performed under this Agreement, procure and maintain the following minimum
insurance coverage to protect the City and Contractor against all loss, claims, damage and
liabilities caused by Contractor, its agents or employees, as indicated below:
A. Comprehensive General liability insurance, with minimum limits of One Million
Dollars ($1,000,000) per occurrence, and Two Million Dollars ($2,000,000) in the
aggregate, with the following coverage details.
1. Premises and Operation
2. Broad Form Property Damages
3. Broad Form Contractual Coverage applicable to this specific Contract,
including any hold harmless and/or indemnification agreement.
4. Personal Injury Coverage with Employee and Contractual Exclusions
removed, with minimum limits of coverage equal to those required for
Bodily Injury Liability and Property Damage Liability.
5. Waiver of Subrogation on behalf of the city.
6. The City of Sunny Isles Beach named as Additional Insured
7. Coverage to be provided on a Non-contributory and Primary format
B. Worker's Compensation and employer's liability coverage, as required pursuant to
Florida law including $1,000,000 Employers' Liability form and Waiver of
Subrogation on behalf of the City of Sunny Isles Beach.
C. Primary Business Automobile Liability with a minimum limit of Liability of
$1,000,000 with the following coverage details:
1. Owned Vehicles.
2. Hired and Non -Owned Vehicles.
3. Employers Non -Ownership
4. Waiver of Subrogation on Behalf of the city.
5. The City of Sunny Isles Beach named as Additional Insured.
6. Coverage to be provided on a Non-contributory and Primary format.
NEON SIGN SOLUTIONS, INC. 4
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
D. Umbrella Liability policy of not less than Two Million Dollars ($2,000,000) per
occurrence.
Insurance required of the Contractor shall be primary to, and not contribute with, any insurance or
self-insurance maintained by the City. Such insurance shall not diminish Contractor's
indemnification and obligations hereunder. The insurance policy shall be issued by companies
authorized to do business under the laws of the State of Florida and acceptable to the City with a
minimum A.M. Best rating of A -Excellent. Before any work under this Agreement is performed,
and at any time upon request, Contractor shall furnish to the City certificates of insurance
evidencing the minimum required coverage and shall be appropriately endorsed for contractual
liability, with the City named as additional insured. All policies shall contain a waiver of
subrogation endorsement. All policies and certificates shall be in forms and issued by insurance
companies acceptable to the City Manager or his designee. All insurance policies and certificates
of insurance shall provide that the policies may not be canceled or altered without thirty (30) days
prior written notice to the City. Contractor shall also require and ensure that each of its sub-
contractors providing services hereunder (if any) procures and maintains, until the completion of
the services, insurance of the types and to the limits specified herein. ANY EXCEPTIONS TO
THE INSURANCE REQUIREMENTS IN THIS SECTION MUST BE APPROVED IN
WRITING BY THE CITY.
WARRANTY OF SERVICES.
A. The Contractor shall warrant the labor performed for a minimum period of one (1)
year from the date the Services are complete. This warranty shall be in addition to
whatever rights the City may have under state or federal law. The Contractor's
obligation under this warranty shall be at its own cost and expense, to promptly
repair or replace (including cost of removal and installation), that item (or part or
component thereof) which proves defective or fails to comply with the Agreement
within the warranty period such that it complies with the Agreement.
B. Contractor warrants to the City that all materials and equipment furnished under
this Agreement will be new unless otherwise specified and will be of good
quality, free from faults and defects and in conformance with the Agreement. All
equipment and materials not conforming to these requirements, including
substitutions not properly approved and authorized, may be considered defective.
If required by City or its designee, Contractor shall furnish satisfactory evidence
as to the kind and quality of materials and equipment. This warranty is not limited
by any other provisions within this Agreement.
C. Contractor shall provide to the City or its designee all manufacturers' warranties.
All warranties, expressed and/or implied, shall be given to the City for all material
and equipment covered by this Agreement. All material and equipment furnished
shall be fully guaranteed by the Contractor against factory defects and
workmanship. At no expense to the City, the Contractor shall correct any and
all apparent and latent defects that are required under state or federal law.
NEON SIGN SOLUTIONS, INC. 5
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
9. DEFECTIVE WORK.
A. The City or its designee shall have the authority to reject or disapprove work
which is found to be defective. If defective work is found, Contractor shall
promptly either correct all defective work or remove such defective work and
replace it with non -defective work. Contractor shall bear all direct and indirect
costs of such removal or corrections including cost of testing laboratories and
personnel.
B. Should Contractor. fail or refuse to remove or correct any defective work or to make
any necessary repairs in accordance with the requirements of this Agreement
within the time indicated in writing by the City Manager or its designee, the City
shall have the authority to cause the defective work to be removed or corrected, or
make such repairs as may be necessary at Contractor's expense. Any expense
incurred by the City in making such removals, corrections or repairs, shall be paid
for out of any monies due or which may become due to Contractor. In the event of
failure of Contractor to make all necessary repairs promptly and fully, which is not
cured in the cure period, the City may declare Contractor in default.
C. If, within one (1) year after the date of completion of Services or such longer
period of time as may be prescribed by the terms of any applicable special
warranty required by the Contract Documents, or by any specific provision(s) of
this Agreement, any of the work is found to be defective or not in accordance with
this Agreement, Contractor, after receipt of written notice from the City or its designee,
shall promptly correct such defective or nonconforming work within the time specified
by the City without cost to the City. Nothing contained herein shall be construed to
establish a period of limitation with respect to any other obligation which
Contractor might have under this Agreement including but not limited to any claim
regarding latent defects.
D. Failure to reject any defective work or material shall not in any way prevent
later rejection when such defect is discovered, or obligate the City to final
acceptance.
E. Where the City or its designee becomes aware of faults, defects or non -conformity
in any of the work provided under this Agreement or with the work being
performed by the Contractor, the City or its designee shall issue a Notice to Cure
to the Contractor for correction. In no event shall the failure of the City or its
designee to bring to the attention of the Contractor of such faults act as a waiver or
release the Contractor from responsibility or liability for such fault, defect or non-
conforming work.
10. TERMINATION AND REMEDIES FOR BREACH.
A. If, through any cause within reasonable control, the Contractor shall fail to fulfill
in a timely manner or otherwise violate any of the covenants, agreements or
stipulations material to this Agreement, the City shall have the right to terminate
the Services then remaining to be performed. Prior to the exercise of its option to
NEON SIGN SOLUTIONS, INC.
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
terminate for cause, the City shall notify the Contractor of its violation of the
particular terms of the Agreement and grant Contractor ten (10) days to cure such
default. If the default remains uncured after ten (10) days the City may terminate
this Agreement, and the City shall receive a refund from the Contractor in an
amount equal to the actual cost of a third party to cure such failure. If Contractor
fails, refuses or is unable to perform any term of this Agreement, City shall pay for
services rendered as of the date of termination.
1. In the event of termination, all finished and unfinished documents, data and
other work product prepared by Contractor shall be delivered to the City and
the City shall compensate the Contractor for all Services satisfactorily
performed prior to the date of termination.
2. Notwithstanding the foregoing, the Contractor shall not be relieved of liability
to the City for damages sustained by it by virtue of a breach of the Agreement
by Contractor and the City may reasonably withhold payment to Contractor for
the purposes of set-off until such time as the exact amount of damages due the
City from the Contractor is determined.
B. Termination for Convenience of City. The City may, for its convenience and
without cause terminate the Services then remaining to be performed at any time
by giving Contractor ten (10) days written notice. The terms of Paragraph 10A(1)
and A(2) above shall be applicable hereunder.
C. Termination for Insolvency. The City also reserves the right to terminate the
remaining Services to be performed in the event the Contractor is placed either in
voluntary or involuntary bankruptcy or makes any assignment for the benefit of
creditors.
11. CONFIDENTIAL INFORMATION. The Contractor shall not, either during the term of
this Agreement or any time for a period of ten (10) years subsequent to that date upon which the
Agreement expires or is terminated for any reason whatsoever, disclose to any person or entity,
other than in the discharge of the duties of the Contractor under this Agreement, any information
which the City designates in writing as "confidential." As a violation by the Contractor of the
provisions of this Section could cause irreparable injury to the City and there is no adequate remedy
at law for such violation, the City shall have the right, in addition to any other remedies available
to it at law or in equity, to enjoin the Contractor from violating such provisions.
12. INDEMNIFICATION AND WAIVER OF LIABILITY. To the fullest extent permitted
by law, the Contractor agrees to indemnify and hold -harmless the City, its agents, representatives,
officers, directors, officials and employees from any claims, liabilities, damages, losses and costs,
including, but not limited to, reasonable attorney fees to the extent cause, in whole or in part, by
the professional negligence, error or omission of the Contractor or persons employed or utilized
by the Contractor in performance of Services under this Agreement. Contractor shall at all times
hereafter indemnify, hold harmless and, at the City's option, defend or pay for an attorney selected
by the City to defend City, its agents, representatives, officers, directors, officials and employees
from and against any and all causes of action, demands, claims, losses, liabilities and expenditures
of any kind, including attorney fees, court costs, and expenses, caused or alleged to be caused by
NEON SIGN SOLUTIONS, INC.
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
the intentional or negligent act of, or omission of Contractor, including those of their employees,
agents, servants, or officers, or accruing, resulting from, or directly related to the subject matter of
this Agreement including, without limitation, any and all claims, losses, liabilities, expenditures,
demands or causes of action of any nature whatsoever resulting from injuries or damages sustained
by any person or property. In the event any lawsuit or other proceeding is brought against City by
reason of any such claim, cause of action or demand, Contractor shall, upon written notice from
City, resist and defend such lawsuit or proceeding by counsel satisfactory to City.
The provisions and obligations of this section shall survive the expiration or earlier termination of
this Agreement. To the extent considered necessary by City, any sum due Contractor under this
Agreement may be retained by City until all of City's claims for indemnification pursuant to this
Agreement have been settled or otherwise resolved; and any amount withheld shall not be subject
to payment of interest by City.
13. JURISDICTION, VENUE AND WAIVER OF JURY TRIAL. This Agreement shall
be interpreted and construed in accordance with and governed by the laws of the State of Florida.
All parties agree and accept that jurisdiction of any dispute or controversy arising out of this
Agreement, and any action involving the enforcement or interpretation of any rights hereunder
shall be brought exclusively in the Eleventh Judicial Circuit in and for Miami Dade County,
Florida, and venue for litigation arising out of this Agreement shall be exclusively in such state
courts, forsaking any other jurisdiction which either party may claim by virtue of its residency or
other jurisdictional device. In the event it becomes necessary for the City to file a lawsuit to
enforce any term or provision under this Agreement and the City is the prevailing parry then the
City shall be entitled to its costs and attorney's fees at the pretrial, trial and appellate levels. BY
ENTERING INTO THIS AGREEMENT, CONTRACTOR AND CITY HEREBY EXPRESSLY
WAIVE ANY RIGHTS EITHER PARTY MAY HAVE TO A TRIAL BY JURY OF ANY CIVIL
LITIGATION RELATED TO THIS AGREEMENT. Nothing in this Agreement is intended to
serve as a waiver of sovereign immunity, or of any other immunity, defense, or privilege enjoyed
by the City pursuant to Section 768.28, Florida Statutes.
14. NOTICES. All notices and other communications required or permitted to be given
under this Agreement by either parry to the other shall be in writing and shall be sent (except as
otherwise provided herein) (i) by certified or registered mail, first class postage prepaid, return
receipt requested, (ii) by guaranteed overnight delivery by a nationally recognized courier service,
or (iii) by electronic mail (e-mail) (with a copy simultaneously sent by certified or registered mail,
first class postage prepaid, return receipt requested or by overnight delivery by traditionally
recognized courier service), addressed to such parry as follows:
If to the City:
Stan Morris
With a copy to:
City Manager
City Attorney
City of Sunny Isles Beach
City of Sunny Isles Beach
18070 Collins Avenue
18070 Collins Avenue
Fourth Floor
Fourth Floor
Sunny Isles Beach, Florida 33160
Sunny Isles Beach, Florida 33160
Tel: (305) 792-1776
Tel: (305) 792-1766
smorris@sibfl.net
aboileau n law.com
If to the
Liessel Ferrer, Project Manager
Contractor:
1 631 West 27th Street
NEON SIGN SOLUTIONS, INC.
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
Hialeah, Florida 33010
Tel: (305) 885-7400
liessel@neonsignsolutions.com
15. PUBLIC RECORDS. The Contractor shall be required to comply with the following
requirements under Florida's Public Records Law:
A. Contractor shall keep and maintain public records required by the City to perform the
service.
B. Upon request from the City, Contractor shall provide the City with a copy of the
requested records or allow the records to be inspected or copied within a reasonable
time at a cost that does not exceed the cost provided by Chapter 119, Florida Statutes,
or as otherwise provided by law.
C. Contractor shall ensure that public records that are exempt or confidential and exempt
from public records disclosure requirements are not disclosed except as authorized by
law for the duration of the contract term and following completion of the contract if the
Contractor does not transfer the records to the City.
D. Contractor shall, upon completion of the contract, transfer, at no cost, to the City all
public records in possession of the Contractor or keep and maintain public records
required by the City to perform the service. If the Contractor transfers all public records
to the City upon completion of the contract, the Contractor shall destroy any duplicate
public records that are exempt or confidential and exempt from public records
disclosure requirements. If the Contractor keeps and maintains public records upon
completion of the contract, the Contractor shall meet all applicable requirements for
retaining public records. All records stored electronically must be provided by
Contractor to the City, upon request from the City, in a format that is compatible with
the information technology systems of the City.
IF THE CONTRACTOR HAS QUESTIONS REGARDING THE
APPLICATION OF CHAPTER 119, FLORIDA STATUTES, TO THE
CONTRACTOR'S DUTY TO PROVIDE PUBLIC RECORDS RELATING
TO THIS CONTRACT, CONTACT THE CITY'S CUSTODIAN OF PUBLIC
RECORDS AT (305) 792-1703, CityClerk@sibfl.net,18070 Collins Avenue, 4th
Floor, Sunny Isles Beach, Florida 33160.
16. AUDIT. The Contractor shall make available to the City or its representative all required
financial records associated with the Agreement for a period of three (3) years.
17. NON-DISCRIMINATION. The Contractor agrees to comply with all local and state civil
rights ordinances and with Title VI of the Civil Rights Act of 1984 as amended, Title VIII of the
Civil Rights Act of 1968 as amended, Title 1 of the Housing and Community Development Act of
1974 as amended, Section 504 of the Rehabilitation Act of 1973, the Americans with Disabilities
Act of 1990, the Age Discrimination Act of 1975, Executive Order 11063, and with Executive
Order 11248 as amended by Executive Orders 11375 and 12086. The Contractor will not
NEON SIGN SOLUTIONS, INC. 9
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
discriminate against any employee or applicant for employment because of race, color, creed,
religion, ancestry, national origin, sex, gender, disability or other handicap, age, marital/familial
status, or status with regard to public assistance. The Contractor will take affirmative action to
ensure that all employment practices are free from such discrimination. Such employment
practices include but are not limited to the following: hiring, upgrading, demotion, transfer,
recruitment or recruitment advertising, layoff, termination, rates of pay or other forms of
compensation, and selection for training, including apprenticeship. The Contractor agrees to post
in conspicuous places, available to employees and applicants for employment, notices to be
provided by the City setting forth the provisions of this non-discrimination clause. The Contractor
agrees to comply with any Federal regulations issued pursuant to compliance with Section 504 of
the Rehabilitation Act of 1973 (29 U.S.C. 708), which prohibits discrimination against the
handicapped in any Federally assisted program.
18. CONFLICT OF INTEREST. The Contractor agrees to adhere to and be governed by
Section 2-11.1, Miami -Dade County Code of Ordinances, as amended, and by Section 33-3, Code
of Ordinances of the City of Sunny Isles Beach, as amended, which are incorporated by reference
herein as if fully set forth herein, in connection with the Agreement conditions hereunder. The
Contractor covenants that it presently has no interest and shall not acquire any interest, directly or
indirectly which should conflict in any manner or degree with the performance of Services under
this Agreement. The Contractor further covenants that in the performance of this Agreement, no
person having any such interest shall knowingly be employed by the Contractor. The Contractor
guarantees that he/she has not offered or given to any member of, delegate to the Congress of the
United States, any or part of this contract or to any benefit arising therefrom.
19. COMPLIANCE WITH LAW. Contractor shall comply with all laws, regulations and
ordinances of any federal, state, or local governmental authority having jurisdiction with respect
to this Agreement and shall obtain and maintain any and all material permits, licenses, approvals
and consents necessary for the lawful conduct of the activities contemplated under this Agreement.
20. CONFLICTING PROVISIONS. The terms and conditions in this Agreement shall
supersede and take priority over any inconsistent or conflicting provisions that are contained in
any other document, including but not limited to Attachments "A," `B," and "C."
21. SCRUTINIZED COMPANIES. Pursuant to Florida Statutes Section 287.135, and
subject to limited exceptions contained therein, a company is ineligible to, and may not, bid on,
submit a proposal for, or enter into or renew a contract with an agency or local governmental entity
for goods or services if at the time of bidding, submitting a proposal for, or entering into or
renewing a contract, the company is on the Scrutinized Companies that Boycott Israel List or is
engaged in the boycott of Israel. Contractors must certify that the company is not participating in
a boycott of Israel. Any contract for goods or services of One Million Dollars ($1,000,000) or more
shall be terminated at the City's option if it is discovered that the company submitted a false
certification, or at the time of bidding, submitting a proposal for, or entering into or renewing a
contract, is listed on the Scrutinized Companies with Activities in Sudan List, the Scrutinized
Companies with Activities in the Iran Terrorism Sectors List, created pursuant to Florida Statute
Section 215.473, or is or has been engaged in business operations in Cuba or Syria, after July 1,
2018.
NEON SIGN SOLUTIONS, INC. 10
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
Any contract entered into or renewed after July 1, 2018 shall be terminated at the City's option if
the company is listed on the Scrutinized Companies that Boycott Israel List or engaged in the
boycott of Israel. Contractors must submit the certification that is attached to this agreement as
Attachment "D." Submitting a false certification shall be deemed a material breach of contract.
The City shall provide notice, in writing, to the Contractor of the City's determination concerning
the false certification. The Contractor shall have ninety (90) days following receipt of the notice
to respond in writing and demonstrate that the determination was in error. If the Contractor does
not demonstrate that the City's determination of false certification was made in error, then the City
shall have the right to terminate the contract and seek civil remedies pursuant to Florida Statute
Section 287.135.
22. E-VERIFY, Florida Statute 448.095 directs all public employers, including municipal
governments, to verify the employment eligibility of all new public employees through the U.S.
Department of Homeland Security's E-Verify System, and further provides that a public employer
may not enter into a contract unless each party to the contract registers with and uses the E-Verify
system. Florida Statute 448.095 further provides that if a Contractor enters into a contract with a
subcontractor, the subcontractor must provide the Contractor with an affidavit stating that the
subcontractor does not employ, contract with, or subcontract with an unauthorized alien. In
accordance with Florida Statute 448.095, Contractor is required to verify employee eligibility
using the E-Verify system for all existing and new employees hired by Contractor during the
contract term. Further, Contractor must also require and maintain the statutorily required affidavit
of its subcontractors. It is the responsibility of Contractor to ensure compliance with E-Verify
requirements (as applicable). To enroll in E-Verify, employers should visit the E-Verify website
(https://www.e-verify.gov/employers/enrolling-in-e-verify) and follow the instructions. The
Contractor must retain the I-9 Forms for inspection, and provide the attached E-Verify Affidavit,
attached hereto as Attachment "E."
23. HUMAN TRAFFICKING. Pursuant to Section 787.06, Florida Statutes, entitled
"Human Trafficking," a governmental entity cannot execute, renew, or extend a contract with a
nongovernmental entity that uses coercion for labor or services, as defined in Section 786.06(2),
Florida Statutes. Contractor must submit the affidavit that is attached to this agreement as
Attachment "F," signed by an officer or an authorized representative of the Contractor, under
penalty of perjury, attesting that Contractor does not use coercion for labor or services as defined
in Section 786.06(2), Florida Statutes. Submitting a false certification shall be deemed a material
breach of contract.
24. MISCELLANEOUS.
A. In the event any provision of this Agreement is found to be void and unenforceable
by a court of competent jurisdiction, the remaining provisions of this Agreement shall nevertheless
be binding upon the parties with the same effect as though the void or unenforceable provisions
had been severed and deleted.
B. This Agreement may be executed in multiple identical counterparts, each of which
shall be deemed an original for all purposes.
NEON SIGN SOLUTIONS, INC. I I
I MO. C'41 I In-; - i Avg iiue,Sunny . Wes:.R�kh, Ftodd A-33 1-60
(365)047466 phone -(305).9-1.4 - 9--3113 Fax
C.. This - Agr'C'erpegit Wi4l 1. '06Tkit-ute th& entire - areementehveert the pa rElties with
res'0.0-t to the subject matte hereof, and itshallsupemde: all previous and contemporaneous.or"al
and written negotlatibm commit.ments. ageement&.0itd.. uiiddrsmdi"Tvgs relating h&etq.
?,My I" flcatfonoth-N AgxeeiriC shAll be etTective Drily if in writihi g and signed
bye the parties. to.thisAgreement.
F. N.b waiv'erdf any provWon qf,(W.Agtem6nt sWil be. valid or 61fbrcimble tireless
IN W-1-TNES-8 WHERE60., 0w parties hereto baye:.executed this.A itemefit in-dup-licatc,
Oil the day and year first Wrlttoit
NEON 'SIdN SOLUTIONS, INC.
:STATE- OF FLORIDA-f-
The (orpgping -histrumerit was-ack' mowledgqd bc.fprc me by means of physical presence or 13
onlinenotarbWon, flils'L 4_44N.,offtbruary-22M. by Jorge. Ida"gai as President of Neon Sio
$01w.-Ions. Inc.
(SEAL)
PLiblic.)
Pergdn6lly Known or ProJoced fdontification
Type of ideptificat On Produced:
or Stamp
-d Nome of Notary
[REMAIN f)-ER OF -PAMINTENT10JALLY LEFTIBLANKI
[SIGNATURE PAGE TO FOLLOW]
i" 11'4C
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
ATT
BY:
Department Head
CITY OF S
BY: V
Larisa S
Mayor
BEACH
APPROVED AS TO FORM
AND LEGAL SUFFICIENCY
BY:
2ain4E. Boileau for Nabors, Giblin
& Nickerson, P.A., City Attorney
NEON SIGN SOLUTIONS, INC. 13
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
Attachment A
NEON SIGN SOLUTIONS, INC. 14
Neon Sign Solutions, Inc.
631 27th St
Hialeah, FL 33010 USA
+13058857400
info@neonsignsolutions.com
neonsignsolutions.com
t."Dl j**9
City of Sunny Isles Beach
18070 Collins Ave
Sunny Isles Beach, FL 33160
United States
ESTIMATE # 2562
DATE 11/01/2024
EXPIRATION DATE 12/02/2024
JOB ADDRESS
18070 Collins Ave
Labor 1 7,700.00 7,700.00
Sign #1: Leahman Causeway Entrance Sign
Labor cost to remove the sign, concrete
foundation and dispose it.
Manufacture 1 74,500.00 74,500.00
Sign #1: Leahman Causeway Entrance Sign
-Type: Single -faced illuminated monument
sign
-Overall Size: 12'-0" x 30'-0" Depth 30"
-Material: Aluminum construction
-Text: "Welcome to Sunny Isles" in
illuminated front lit letters.
letters to have standard translucent color
vinyl overlay.
-Design Elements: Illuminated wave pieces
-Base: 26 " High Aluminum construction with
stucco finish.
-Decorative Features: Vertical pieces made
of aluminum with yellow reflective vinyl
overlay.
-Logo: City logo in push thru acrylic
illuminated.
Description: This monument sign serves as a
welcoming entrance to Sunny Isles,
combining durable aluminum materials with
eye-catching illumination. The design
includes dynamic wave elements and an
elegant masonry finish, enhancing the
overall aesthetic appeal. The city logo is
prominently displayed in dimensional
acrylic lettering to be illuminated
ensuring visibility and recognition.
Manufacture 1 850.00 850.00
Sample of Monument Sign
Manufacture illuminated Letter with
translucent vinyl overlay mounted over
vertical bars with yellow reflective vinyl.
Installation
1 13,700.00
13,700.00
Installation of above sign will include
concrete foundation.
Part
1 6,650.00
6,650.00
LinearPro Wall Washer, LED
White XXOOK, 36W, IP66,
ON/OFF, XXXX beam angle,
grey, 1190mm length.
Installation
1 2,300.00
2,300.00
Install the Linear Pro Wallwasher on a
concrete pad.
Installation
1 2,700.00
2,700.00
Stand off Aluminum Brackets
Engineering
1 3,200.00
3,200.00
Plans signed and seal by the engineer
Engineering
1 600.00
600.00
MOT Plans
Equipment
4 1,000.00
4,000.00
Traffic Signs, set up - 4 days
Sign #2
Labor
1 3,500.00
3,500.00
Sign #2: Monument Sign at Government Center
Labor cost to remove the sign, foundation
and dispose it.
Note: We are not responsible to repair any
concrete slab floor area after sign
removal.
Manufacture
1 35,000.00
35,000.00
Sign #2: Monument Sign at Government Center
-Type: Double-faced illuminated sign - V
Shape Sign
-Material: Aluminum construction.
-Panel Material: Aluminum panels with
routed faces and acrylic push-thru letters.
-Decorative Elements: Yellow decorative
details will be illuminated channel pieces.
-Base Material: Constructed from aluminum
with stucco finish.
-Logo: City logo in acrylic, laser -cut
dimensional letters.
-Overall Dimensions: 8'-0" H x 5'-0" W
Description: This illuminated monument sign
at the Government Center is designed for
high visibility and aesthetic appeal.
Featuring double-faced construction with
acrylic push-thru letters, the sign
effectively communicates important
information. The yellow decorative details
add a distinctive touch, while the aluminum
base ensures durability. The city logo is
prominently displayed with dimensional
acrylic lettering, enhancing recognition
and brand identity.
Installation
1 12,000.00
12,000.00
Install (1) aluminum monument sign.
Including concrete foundation.
Install cost does not include any
additional work on the concrete slab floor.
Engineering
1 2,500.00
2,500.00
Plans signed and seal by the engineer.
Sign #3
Labor
2 2,800.00
5f600.00
Sign #3: Sunny Isles Median Welcome Signs
Labor cost to remove the sign, foundation
and dispose it.
Qty=2
Manufacture
2 16,000.00
32,000.00
Sign #3: Sunny Isles Median Welcome Signs
Qty=2
-Type: Single -sided illuminated monument
sign
-Material: Aluminum construction
-Lettering: Routed faces with push-thru
acrylic letters.
-Decorative Elements: Yellow bars
illuminated channel pieces.
-Base Material: Aluminum base
-Overall Dimensions: 5'-0" W x 10'-0" H
Description: The Sunny Isles Welcome Sign
is designed to create a warm and inviting
atmosphere for visitors. This single -sided
illuminated sign features durable aluminum
construction and showcases routed faces
with vibrant push-thru acrylic letters. The
decorative yellow bars enhance its visual
appeal, while the aluminum base provides
stability and longevity. This sign serves
as a prominent landmark, welcoming guests
to the community with style and elegance.
Installation
2 5,500.00
11,000.00
Install (2) Illuminated monument sign.
Concrete Foundation include it.
Engineering
2 1,000.00
2,000.00
Plans signed and seal by the engineer.
Engineering
2 600.00
1,200.00
MOT plans
Equipment
6 1,000.00
6,000.00
Traffic Signs Rental- Set up- 3 days (per
sign)
Sign#4
Labor
14 3,500.00
49,000.00
Sign #4: Neighborhood & Park Monument Sign.
Labor cost to remove the sign, foundation
and dispose it.
Manufacture
7 22,800.00
159,600.00
Sign #4: Neighborhood & Park Monument Sign.
-Type: Single -sided illuminated monument
sign
-Material: Aluminum construction.
-Lettering: Routed faces with push-thru
acrylic
-Decorative Elements: Wave design at the
top, constructed from aluminum.
-Text: Push thru acrylic letters
-Logo: City logo in laser -cut abrylic
pieces
-Overall Dimensions: 9'-0" H x 12.83' W
Description: The Monument Sign is a
striking single -sided illuminated sign that
enhances the park's entrance. Constructed
from durable aluminum, the sign features
routed faces with vibrant push-thru acrylic
letters, ensuring visibility from both
sides. The wave decoration at the top adds
a dynamic touch, while the city logo is
beautifully presented with laser -cut
acrylic pieces. This sign serves as a
prominent landmark, inviting visitors to
enjoy the scenic beauty of Intracoastal
Park.
Manufacture
Sign #4 D/S: Neighborhood & Park Monument
Sign.
-Type: Double -sided illuminated monument
sign
-Material: Aluminum construction.
-Lettering: Routed faces with push-thru
acrylic
-Decorative Elements: Wave design at the
top, constructed from aluminum.
-Text: Push thru acrylic letters
-Logo: City logo in laser -cut acrylic
pieces
-Overall Dimensions: 9'-0" H x 12.83' W
Description: The Monument Sign is a
striking double -sided illuminated sign that
enhances the park's entrance. Constructed
from durable aluminum, the sign features
routed faces with vibrant push-thru acrylic
letters, ensuring visibility from both
sides. The wave decoration at the top adds
a dynamic touch, while the city logo is
beautifully presented with laser -cut
acrylic pieces. This sign serves as a
prominent landmark, inviting visitors to
enjoy the scenic beauty of Intracoastal
Park.
Installation
Install (14) Monument Sign
including concrete foundation.
7 26,256.00
14 10,700.00
183,792.00
149,800.00
Engineering 14 1,000.00 14,000.00
Plans signed and seal by the engineer.
Engineering
14
600.00
8,400.00
MOT Plans
Equipment
14
1,000.00
14,000.00
Traffic Signs Rental- Set up- 3 days (per
sign)
Sign #5
Labor
1
6,800.00
6,800.00
Sign #5
Sunny Isles Blvd Sign
Remove and dispose existing sign.
Manufacture
1
15,840.00
15,840.00
Manufacture one (1) set of led illuminated
front lit letters mounted on a radius
raceway.
1/8" Aluminum construction, .063 aluminum
returns, 3/16" Acrylic faces.
To read: Sunny Isles Beach
Size: 3'-10" High
Manufacture
1
4,500.00
4,500.00
Radius Raceway
Size: 12" x 54'
Installation
1
3,800.00
3,800.00
Install (1) set of illuminated letters
mounted on raceway.
Manufacture
1
18,750.00
18,750.00
Manufacture one (1) Front lit illuminated
logo
mounted on a wireway and illuminated pieces
will be mount it on top of it.
Size:96" x 172"
Manufacture
1
4,500.00
4,500.00
Install (1) illuminated logo mounted on
wireway.
Equipment
1
4,500.00
4,500.00
Crane Rental (2) days.
Equipment
1
7,500.00
7,500.00
125' Boomlift Rental (1) Week
Engineering
1
lf500.00
1,500.00
Plans Sign and seal by the engineer
Engineering
1
700.00
700.00
MOT Plans
Equipment
1
1,500.00
1,500.00
Traffic Control Signs
Labor
1
300.00
300.00
Labor to install astronomical battery back
up timer.
Part
1
300.00
300.00
Astronomical battery back up timer.
Labor
1
8,000.00
8,000.00
Project Management
Design Fees
19 480.00
9,120.00
Design Permit Drawings
Labor
1 10,000.00
10,000.00
Mobilization
Permit process
1 9,000.00
9,000.00
Permit Processing
Inspections
1 8,500.00
8,500.00
Obtain final inspections
Permit process
1 9,000.00
9,000.00
FDOT permit process
City fees
1 10,000.00
10,000.00
FDOT Permit Fees.
City fees
1
0.00
City permit fees will be paid by the City.
City MOT costs for police patrol will be
paid by the City.
Note: Additional charges may apply
depending on the ROW permit requirements.
Final designs in scale must be provide by
the City.
We only run up to 5' of electric.
Deposit will be required as follows:
- No deposit to initiate the project.
William Lehman Causeway (1)
20% -After Permit Approval.
30%- After each sign or group of signs are
manufactured, approved, and inspected by
the city.
50% -Upon completion of each sign or group
of signs ate installed.
Island Median Welcome Signs (2)
20% -After Permit Approval.
30%- After each sign or group of signs are
manufactured, approved, and inspected by
the city.
50% -Upon completion of each sign or group
of signs are installed.
Sunny Isles Blvd. Sign (1)
20% -After Permit Approval.
30%- After each sign or group of signs are
manufactured, approved, and inspected by
the city.
50% -Upon completion of each sign or group
of signs are installed.
Government Center Monument (1)
20% -After Permit Approval.
30%- After each sign or group of signs are
manufactured, approved, and inspected by
the city.
50% -Upon completion of each sign or group
of signs are installed.
Neighborhood / Monument (Single Face) (7)
20% -After Permit Approval.
30%- After each sign or group of signs are
manufactured, approved, and inspected by
the city.
50% -Upon completion of each sign or group
of signs are installed.
Neighborhood / Monument (Double Face) (7)
20% -After Permit Approval.
30%- After each sign or group of signs are
manufactured, approved, and inspected by
the city.
50% -Upon completion of each sign or group
of signs are installed.
Any changes or modifications requested
after the initial agreement may result in
additional charges.
We are not responsible to repair any
landscape in case gets damage during the
installation or removal.
New Landscape is not include it on the
estimate.
Base of the signs are going to be aluminum
and stucco finish,
The oyster concrete shell finish is not
include it on the estimate.
City of Sunny Isles is responsible to run
the electrical to the signs.
Warranty Information
Electrical Parts Warranty: Three years
(applicable if the sign is controlled by a
timer)
Paint Warranty: Three years
Installation Warranty: Five years
ACH Payments to: Chase
Routing Number: 267084131
Account Number: 868575876
SUBTOTAL 939,702.00
TAX 0.00
TOTAL $ 9 3 9 F 7 0 2. 0 0
Accepted By Accepted Date
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
Attachment B
NEON SIGN SOLUTIONS, INC. 15
Miami -Dade County
Solicitation RTQ-00918
Solicitation RTCD0918
Signs and Banners: Purchase, Installation, & Removal
Solicitation Designation: Public
IA
Miami Dade County
5/3/2019 7:48 AM p• 1
Miami -Dade County
Solicitation RTQ-00918
Solicitation RTQ00918
Signs and Banners: Purchase, Installation, & Removal
Solicitation Number RTQ 00918
Solicitation Title Signs and Banners: Purchase, Installation, & Removal
Solicitation Start Date Jun 13, 2018 5:05:18 PM EDT
Solicitation End Date Jun 28, 2018 6:00:00 PM EDT
Question & Answer Jun 20, 2018 12:00:00 PM EDT
End Date
Solicitation Contact Mary Hammett
305 375-5471
mhammet@miamidade.gov
Solicitation Contact Jessica Tyrrell
Procurement Contracting Manager
ISD
305 375-4029
tyrrell@miamidade.gov
Contract Duration
See Bid Documents
Contract Renewal
See Bid Documents
Prices Good for
See Bid Documents
Solicitation Comments his Request to Qualify (RTQ) will establish a List of Prequalified Vendors (List) that will be used to solicit
)r the purchase, installation, and removal of signs and banners fdit kftunty.
Item Response Form
Item tTQ 00918--01-01 -Signs and Banners, Purchase & Installation
Quantity 1 each
Prices are not requested for this item.
Delivery Location Miami -Dade County
No Location Specified
aQty
Description
Signs and Banners, Purchase & Installation
5/3/2019 7:48 AM p. 2
Miami -Dade County
Solicitation RTQ-00918
;W1111
CBUNTY
- SOLICITATION NO.: RTQ 00918
MIANDADE COUNTY, FLORIDA
REQUEST TO QUALIFY
TITLE
Signs and Banners: Purchase, Installation, & Removal
FOR INFORMATION CONTACT
Mary Hammet473Q5 5471, mhammet@miamidade.gov
IMPORTANT NOTICE TO BIDDERS/PROPOSERS:
• READ THE ENTIRE SOLICITATION DOCUMENT, THE GENERAL TERN
CONDITIONS, AND HANDLE ALL QUESTIONS IN ACCORDANCE WITH THE
OUTLINED IN PARAGRAPH 1.2(D) OF THE GENERAL TERMS AND CONDITIONS.
• THE SOLICITATION SUBMITTAL FORM CONTAINS IMPORTANT INFORMATI
REQUIRES REVIEW AND COMPLETION BY ANY BIDDER/PROPOSER RESPOI
THIS SOLICITATION.
• FAILURE TO COMPLETE AND SIGN THE SOLICITATION SUBMITTAL FOF
RENDER YOUR PROPOSAL MEMO NSIVE.
5/3/2019 7:48 AM P. 3
Miami -Dade County
Solicitation RTQ-00918
MtAHMWFjN
SECTION 1
GENERAL TERMS AND CONDITIONS:
All general terms and conditions of Miami Dade County Procurement Contracts are posted online. Bidders/Proposers
that receive an award frem Miami Dade County through Miami Dade County's competitive procurement process must
anticipate the inclusion of these requirements in the resultant Contract. These general terms and conditions are
considered -non negotiable.
All applicable terms and conditions pertaining to this solicitation and resultant contract may be viewed online at the
Miami Dade County Procurement Management website by clicking on the below link:
http://www.miamidade.gov/procurementAibrary/boilerplate/grtmwrW axdconditions -r18- Lpdf
NOTICE TO ALL BIDDERS/PROPOSERS:
Electronic bids are to be submitted through a secure mailbox at BidSync (www.bidsync.c#until the date and time as
indicated in this Solicitation document. It is the sole responsibility of the Bidder/Proposer to ensure their proposal
reaches BidSync before the Solicitation closing date and time. There is no cost to the Bidder/Proposer to submit a
proposal in response to a Miami Dade County solicitation via BidSync. Electronic proposal submissions may require
the uploading of electronic attachments. The submission of attachments containing embedded documents or
proprietary file extensions is prohibited. All documents should be attached as separate files.
For information concerning technical specifications please utilize the questionlanswer feature provided by BidSync at
www.bidsync.com within the solicitation. Questions of a material nature must be received prior to theUbte
specified in the solicitation. Material changes, if any, to the solicitation terms, scope of services, or bidding procedures
will only be transmitted by written addendum. (See addendum section of BidSync site).
Please allow sufficient time to complete the online forms and upload of all proposal documents. Bidders/Proposer
should not wait until the last minute to submit a proposal. The deadline for submitting information and documents will
end at the closing time indicated in the solicitation. All information and documents must be fully entered, uploaded,
acknowledged (Confirm) and recorded into BidSync before the closing time or the system will stop the process and the
response will be considered late and will not be accepted.
PLEASE NOTE THE FOLLOWING:
No part of your proposal can be submitted via HARDCOPY, EMAIL, OR iaUariation in price or conditions shall
be permitted based upon a claim of ignorance. Submission of a proposal will be considered evidence that the
Bidder/Proposer has familiarized themselves with the nature and extent of the work, and the equipment, materials, and
labor required. The entire proposal response must be submitted in accordance with all specifications contained in the
solicitation electronically.
5/3/2019 7:48 AM p. 4
Miami -Dade County
Solicitation RTQ-00918
SECTION 2
SPECIAL TERMS AND CONDITIONS
2.1 PURPOSE
This Request to Qualify (RTQ) will establish a List of Prequalified Vendors (List) that will be used to solicit for the
purchase, installation, and removal of signs and banners for Miami -Dade County (County). Placement on the
List is not a contract between the County and the Vendor, but an acknowledgement that the Vendor meets the
qualifications as outlined throughout this RTQ. Vendor Submittals are accepted throughout the term of the RTQ
for placement on such List.
2.2 DEFINITIONS
Invitation to Quote (ITQ) — Shall refer to the solicitation of quotes from the List of Prequalified Vendors for
specific goods and/or service; and awarded based on lowest price, or other quantifiable criteria.
List of Prequalified Vendors (List) — Shall refer to business entities/individuals determined by the County's
Internal Services Department, Procurement Management Division, as meeting the minimum standards of
business competence, financial ability, and/or product quality for placement on the List of Prequalified Vendors,
and who may submit quotes/proposals, at the time of need.
Vendor— Shall refer to a business entity/individual responding to this RTQ.
Submittal - Shall refer to the forms submitted in response to this RTQ.
Work Order Proposal Request (WOPR) — Shall refer to the solicitation of offers from the List of Prequalified
Vendors for specific goods and/or services; and evaluated and awarded based on best value.
2.3 TERM
This List shall be established on the first calendar day of the month succeeding approval by the Board of County
Commissioners, or designee, unless otherwise stipulated in the Blanket Purchase Order issued by the Internal
Services Department, Procurement Management Division. The List shall expire on the last day of the last month
of the five (5) year term.
2.4 QUALIFICATION CRITERIA
Vendors shall meet the following criteria to be considered for placement on the List; and for participation in future
competitions for the following groups:
Group 1: Purchase of Signs and Banners
Group 2: Purchase, Install, and/or Removal - Non -Electrical Signs and Banners
Group 3: Purchase, Install, and/or Removal - Electrical Signs and Banners
Qualification for all Groups:
1. Vendors shall provide the contact information of a designated representative to provide the County with
support and information concerning orders placed and to receive future spot market competitions. Vendors
shall provide the representative's name, phone number, and email address.
Additional Qualification for Group 2:
5/3/2019 7:48 AM P 5
Miami -Dade County
Solicitation RTQ-00918
2. Vendors shall submit one of the following:
a. A valid Certification for Sign Specialty Electrical Contractor issued by the State of Florida.
b. A valid Certification for Electrical Contractor issued by the State of Florida.
c. A valid Business Certificate of Competency for Master Electrical Sign Contractor issued by Miami -
Dade County.
d. A valid Business Certificate of Competency for Non -Electrical Sign Contractor issued by Miami -
Dade County.
e. A valid Certification for General Contractor issued by the State of Florida.
Additional Qualification for Group 3:
3. Vendors shall submit one of the following:
a. A valid Certification for Sign Specialty Electrical Contractor issued by the State of Florida.
b. A valid Certification for Electrical Contractor issued by the State of Florida.
c. A valid Business Certificate of Competency for Master Electrical Sign Contractor issued by Miami -
Dade County.
d. A valid Business Certificate of Competency for Master Electrical Contractor issued by Miami -Dade
County
e. A valid Certification for General Contractor issued by the State of Florida.
Vendors shall provide all of the specified information, documents, and attachments listed above with their
Submittal as proof of compliance with the requirements of this RTQ. However, the County may, at its sole
discretion and in its best interest, allow Vendors to complete, supplement or supply the required documents
throughout the term of the RTQ. It shall be the sole right of the County to determine the number of Vendors who
will be included in the List. During'the term of the RTQ, the County reserves the right to add or delete Vendors
as it deems necessary and in its best interest.
2.5 SMALL BUSINESS ENTERPRISES (SBE) MEASURES (GROUP 3)
All work orders shall be submitted to Small Business Development for review and application of SBE-Con
measures.
2.6 INSURANCE
Insurance is not required in order to be prequalified under this RTQ. Insurance requirements will be detailed in
the subsequent ITQ or WOPR.
2.7 SPOT MARKET QUOTES
Vendors on the List will be invited to participate in spot market competitions, as needed. When a requirement to
procure goods and/or services listed under a specific group is identified, Vendors on the List under that group
will be invited to quote. When a requirement to procure goods and services falls under multiple groups, Vendors
on the List under the combination of groups will be invited to quote. The County, at its sole discretion and in its
best interest, may choose to quote goods and services in the combination that best meets its needs.
The spot market competitions will be in the form of an ITQ or WOPR that will include the specific goods and/or
services required, and may include provisions, as applicable, such as:
• Small Business Measures
• Warranty Requirements
• Liquidated Damages
• Living Wage
5/3/2019 7:48 AM p. 6
Miami -Dade County
Solicitation RTQ-00918
For federally funded programs, additional provisions may apply in accordance with the funding source. The
following provisions from Section 1, General Terms and Conditions shall be exempted from such solicitations, as
indicated in the ITQ or WOPR.
• Local Preferences
• User Access Program (UAP) Fee
• Small Business Enterprises (SBE) Measure
• Local Certified Service -Disabled Veteran's Business Enterprise Preference
• First Source Hiring Referral Program
• Prompt Payment Terms
• Office of Inspector General Fee
5/3/2019 7:48 AM p. 7
Miami -Dade County
Solicitation RTQ-00918
SECTION 3
SCOPE OF WORK
3.1 SCOPE OF WORK
It is the intent of this solicitation to identify and make available to the County purchase, installation, and removal
of signs and banners.
3.2 GOODSISERVICES TO BE PROVIDED
Group 1: May include, but not be limited to, vinyl banners and signs, plywood signs, plastic signs,
metal/aluminum signs, non -electrical signs, electrical signs, graffiti proof signs, construction signs, neon signs,
LED signs, electronic scoreboards, etc.
Group 2: Turn -key projects (purchase, install, and/or removal) that include non -electrical signs such as vinyl
banners and signs, plywood signs, plastic signs, graffiti proof signs, construction signs, metal/aluminum signs,
etc. and associated installation and removal.
Group 3: Turn -key projects (purchase, install, and/or removal) that include electrical signs such as neon signs,
LED signs, electronic scoreboards, fiber optic banners, etc. and associated installation and removal.
5/3/2019 7:48 AM P. 8
Miami -Dade County
Solicitation RTQ-00918
SECTION 4
SUBMITTAL FORM
SUBMITTER:
QUAL'IFIGATION CRITERIA
TO BE COMPLETED'BY ALL SUBMITTERS
Refer to Section 2.4, Qualification Criteria to ensure that Submittal complies with solicitation requirements.
Groups
(Indicate with an Y in the box for each group Vendor wishes to prequalify.)
Group 1
Purchase of Signs and Banners
❑
Group 2
Purchase, Install, and/or Removal - Non -Electrical Signs and Banners
❑
Group 3
Purchase, Install, and/or Removal - Electrical Signs and Banners
❑
Reference
Requirements
Copy
Section
Attached
Vendors shall provide the contact information of a designated representative to
provide the County with support and information concerning orders placed and to
receive future spot market competitions. Vendors shall provide the representative's
name, phone number, and email address.
2A (1)
All Groups
Representative Name:
Phone Number:
E-Mail Address:
Vendors shall provide a copy of one of the following:
a. A valid Certification for Sign Specialty Electrical Contractor issued by the
❑
State of Florida; or
b. A valid Certification for Electrical Contractor issued by the State of Florida; or
El
2.4(2)
C. A valid Business Certificate of Competency for Master Electrical Sign
❑
Group 2
Only
Contractor issued by Miami -Dade County; or 1
d. A valid Business Certificate of Competency for Non -Electrical Sign
❑
Contractor issued by Miami -Dade County.
e. A valid Certification for General Contractor issued by the State of Florida.
:[JI
5/3/2019 7:48 AM P. 9
Miami -Dade County
Solicitation RTQ-00918
Vendors shall provide a copy of one of the following:
a. A valid Certification for Sign Specialty Electrical Contractor issued by the
❑
State of Florida; or
2.4(3)
b. A valid Certification for Electrical Contractor issued by the State of Florida; or
❑
Group 3
Only
c. A valid Business Certificate of Competency for Master Electrical Sign
❑
Contractor issued by Miami -Dade County; or
d. A valid Business Certificate of Competency for Master Electrical Contractor
❑
issued by Miami -Dade County.
e. A valid Certification for General Contractor issued by the State of Florida.
❑
5/3/2019 7:48 AM P. 10
Miami -Dade County
Solicitation RTQ-00918
lr111 i� "1 SuWttal Form.
Solicitation NYi9ttil'Q Solicitation Title: Signs and Banners: Purchase, Installation, & Removal
Legal Company Name (include dlbla if applicable):
Federal Tax Identification Number:
I
State incorporated/Organized:
If Corporation Date Incorporated/Organized
Company Operating Address:.
(-�
Code
I
MlemDade County Address (if applicable):
Code
F
Company Contact Person:
Email Address:
Phone Number
Company s Internet Web Address:
(include area code): !
.... ......... .............. ..... ............._...__
Pursuant to MiaWde County Ordinanod4k4any individual, corporation, partnership, joint venture or other legal entity havinc
officer, director, or executive who has been convicted of a felony during the past ten (10) years shall disclose this Informal
entering into a contract with or receiving funding from the County.
❑ Place a check mark here only if the Bidder has such conviction to disclose to comply with this requirement.
lQrAI PR FFR NC CFRTI1FICATJ0g{e purpose of this certification, and pursuant to Section 2-8.5 of the Code of "grade County, a
'local business a business located within the limits otDutideiCounty that has a valid Local Business Tax Receipt issalgdd W Gbamtiy
least one year prior to bid submission; has a physical business address located within4had'erfii9udtVFao>ih which business is performed
and which served as the place of employment for at least three full time employees for the continuous period of one year prior to bid
exception, if the business is a certified Small Business Enterprise, the local business location must have served as the place of employment f
employee); and contributes to the economic development of the community in a verifiable and measurable way. This may include, but not be limited to, the
retention and expansion of employment opportunities and the support and increbt utbAm County
❑ Place a check mark here only if affirming the Bidder meets the requirements for Local Preference. Failure to complete this certification at this
time (bv checking the box above may render the vendor ineligible for Local Preference
I QQAl 1-i9 AQ011ART RFn RUS1N sS CFRT1FMpbTJJWurpose of this certification, and pursuant to Section 2-8.5 of the Code of
MiamiDade County(mally-headquartered busii9esa Local Business wl ipal place of busirift tiami -Dade County.
❑ Place a check mark here only If affirming thnlEWmquirements for the L f)quartered Preference (IIFi I)jre to
complete this certification at this time (by checking the box) may render the vendor ineligible for the LHP
The address of the Lodaidgdquartered office is:
LOCAL CERTIFIED VETERAN BUSINESS ENTERPRISE CERIUJOAT110Nified Veteran Business Enterprise is a firm that is (a) a local
business pursuant to SectMbf the Code of N@ade County and (b) prior to bid submissidild d by the State of Florida Department of
Management Services as a veteran business enterprise pursuant to Section 295.187 of the Florida Statutes.
❑ Place a check mark here only if affirming theslAilddat Certified Veteran Business Enterprise. A copy of the certification
must be submitted with the bid.
SMALL BUSINESS ENTERPRISE CONTRACT MEASURES (lf Applicable)
A Small Business Enterprise (SEE) must be certified by Small Business Development for the type of gocHWdegVw%ddeedesattmrdance
with the applicable Commodity Code(s) for this Solicitation. For certification information contact Small Business De36HP0reastratJ§05) 37
hftp:/Iwww.miamidade.gov/smallbusiness/ceoWDWdms.agoe SBE must be certified by the solikibittunission deadline, at contract award, and
for the duration of the contract to remain eligible for the preference. Firms that graduate from the SBE program during the contract may remain on the contract.
5/3/2019 7:48 AM
P. 11
Miami -Dade County
Solicitation RTQ-00918
Is Biddellfirm a Mian4Dade County Certified Small Business Enterprise? Yes D .D
If yes, please provide Certification Number.
SCRUTINIZED COMPANIES MTH ACTIVITIES IN SUDAN LIST OR THE SCRUTINIZED COMPANIES WITH ACTIVITIES IN THE h
PETROLEUM ENERGY SECTOR LIST:
By executing this bid through a duly authorized represeBiatlfidsdhat the Biddes not on the Scrutinized Companies with Activities in Sudan
List or the Scrutinized Companies with Activities in the Iran Petroleum Energy Sector List, as those terms are used and defined in sect!
215,473 of the Florida Statutes. In the evenBttldbtlsamable to provide such certification but still seeks to be considered for award of this soli
theBiddelshall execute the bid response package through a duly authorized representative and shall ar-s lepedeevent, the
Biddeshall furnish together with its bid response a duly executed written explanation of the facts supporting any exception to the requireme
that it claims under Section 287.135 of the Florida Stdiiddee§hees to cooperate fully with the County in any investigation undertaken b)
County to determine whether the claimed exception would be applicable. The County shall have the right to terminate any contract resulting from this
solicitation for default i8l0deis found to have submitted a false certification or to have been placed on the Scrutinized Companies for Activiti
List or the Scrutinized Companies with Activities in the Iran Petroleum Energy Sector List.
IT IS HEREBY CERTIFIED AND AFFIRMED THAT THE BIDDER SHALL ACCEPT ANY AWARDS MADE AS A RESULT
SOLICITATION. BIDDER FURTHER AGREES THAT PRICES QUOTED WILL REMAIN FIXED FOR A PERIOD OF ONE HUNI
EIGHTY (180) DAYS FROM DATE SOLICITATION IS DUE.
WAIVER OF CONFIDENTIALITY AND TRADE SECRET TREATMENT OF BID
The Bidder acknowledges and agrees that the submittal of the Bid is govdsr®d\bVrfrtwMdn the Sunshine Laws and Public Records Laws
as set forth in Florida Statutes Section 286.011 and Florida Statutes Chapter 119. As such, all material submitted as part of, or in support of, the bid will be
available for public inspection after opening of bids and may be considered by the County in public.
By submitting a Bid pursuant to this Solicitation. Bidder agrees that all such materials may be considered to be public records. The
Bidder shall not submit any information in response to this Solicitation which the Bidder considers to be a trade secret, pry
renfidantial_
In the event that the Bid contains a claim that all or a portion of the Bid submitted contains confidential, proprietary or trade secret Information
signing below, knowingly and expressly waives all claims made that the Bid, or any part thereof no matter how indicated, is confidential, p
trade secret and authorizes the County to release such information to the public for any reason.
Acknowledgment of Waiver:
Bidd6s Authorized Represehtafiftnature:
e
Twe or Print Name
TvDe or Print Title
THE EXECUTION OF THIS FORM CONSTITUTES THE UNEQUIVOCAL OFFER ORXEIE BMgER BY THE TERMS OF ITS
OFFER. FAILURE TO SIGN THIS SOLICITATION WHERE INDICATED ABOVE BY AN AUTHORIZED REPRESENTATIVE SHAI
THE BID NGRESPONSIVE. THE COUNTY MAY, HOWEVER, IN ITS SOLE DISCRETION, ACCEPT ANY RESPONSE THAT INCLUDES AN
EXECUTED DOCUMENT WHICH UNEQUIVOCALLY BINDS THE BIDDER TO THE TERMS OF ITS OFFER.
Bidd6s Authorized Represelitagignature:
e
Type or Print Name
Type or Print Title
5/3/2019 7:48 AM p. 12
Miami -Dade County Solicitation RTQ-00918
M,A1W�iA�7�
FAIR SUBCONTRACTING PRACTICES
In compliance with MiN ode County Code SectiBrl Ahe Bidder/Proposer shall submit with the proposa
statement of its policies and procedures (use separate sheet if necessary) for awarding subcontract(
❑ NO SUBCONTRACTORS WILL BE UTILIZED FOR THIS CONTRACT
Signature Date
5/3/2019 7:48 AM p. 13
Miami -Dade County
Solicitation RTQ-00918
SUBCONTRACTORISUPPLIER LISTING
(MiamDadeCounty CodeSeStkal.RaiNi O
Name of Bidder/Propos '10.
n accordance with Sectiodlt,88.8 and 10.34 of the M®ade County Code, this form must be submitted as a condition of award by all Biddenu?naposers on County contracts for purchase of supplies, materials or services,
Winding professional services which Involve expenditures of $100,000 or more, and a0 Proposers an County, or Public Health Trust consliucfion contracts which Involve expenditures of $100,000 ormore. The Bidder/Proposerwho is
warded this contract shall not change or substitute first bar subcontractors or direct suppliers or the portions of the contract work to be performed or materials to be supplied from those Identified, except upon written approval of tl
�Dturty. The Bidder/Proposershould enter the word NONE' under the appropriate heading of this form if no subcontractors or suppress will be used on the contract and sign the form below.
In accordance with Ordinance BDladEntity contracting with the County shall report the race, gender and elhnloorigin of the owners and employees of ad first der subconlractomleupiffiethe event that the recommended
idder Pr000serd monslmtea to the Coun rior to award that the race nder and ethnic Information is not reasonablyavailable a he time the Bidder/Pro user shall be obligated to exercise diligent efforts to obtain that Informed.
nd rovide the same to me Coun not latermlin ten 10 des after it becomes available and, in en event, rierto fine ayment under the contract
(Please duplicate this form If additional space is needed.)
3uppliest
Principal Owner
Emp oyea(s)
Business
Materials/
(Enter the number of male and female owners by racalethnlcity)
(Enter the number of male and female employees and the number of
Name and
Principal
Services to Ic
mployeas by racelefhnicity)
Native
Native
Address of
Owner
Provided by
First Tter Dire
Supplier
M
F
White
Black
Hispanic
01rtc
Americo
Other
M
F
Whim
Black
Hispanic
Other
Supplier
Iaiander
Native
Islander
Nativeart
Native
ken
i
F-
�
F-.-F_F__F_F__�
F__F
F_ F_
mployae(a)
(Enter the number of male and
F___
female employees
—
F__ F__I (.
and the number of
Business
ocope or wo
to he
Principal Owner
No sand
Address
Performed by
(Enhrthanumberef-li end/emdeowners byracdathnidty)
em to ass b
racalethnldly
of
First Tier
Principal
Owner
Subcontract
Native
Native
Subcontract
Subeonsulta
M
F
White
Black
Hispanle
chic
Islander
American
Native
Omer
M
F
White
Black
Hlspsnte
lalandar
American
NaBve
Omar
Subconsulta
kan
j
t
Midark hen if rag, gender and ethnicity Infmmatlon is not available and will be provided at a later data. Tha data may be aubmitled to centractlng department or on line to the Small Bueihtlpgv0aveigWiagaatMYietlrdlmlmssarvtces Department at
developmmalantracts.ceps a condition of final payment,Bidder/Proposer shall provide subcontractor Information on the Subcontractor Payment Report Sub 200Hd4olwkh&rdmn*A lmgddbusines.Ilibmryl(orms/subgayra*64Wf
I certify that the representations contained in this Subcontractor/Suppharllsting are to the best of my knowledge true and accurate.
Signature of Bidder/Proposer Print Name Print Title
5/312019 7:48 AM p. 14
Miami -Dade County Solicitation RTQ-00918
-MiamDade County
Contractor Due Diligence Affidavit
Per MiamDade County Board of County Commissioners (BoardliStesoluti9tftirity Vendors and Contractors shall disclose the foil,
condition of award for any contract that exceeds one million dollars ($1,000,000) or that otherwise must be presented to the Board fo
(1) Provide a list of all lawsuits in the five (5) years prior to bid or proposal submittal that have been filed against the firm, its dire
and/or board members based on a breach of contract by the firm; include the case name, number and disposition;
(2) Provide a list of any instances in the five (5) years prior to bid or proposal submittal where the firm has defaulted; include
circumstances;
(3) Provide a list of any instances in the five (5) years prior to bid or proposal submittal where the firm has been debarred or rE
non compliance or nperformance, such as a notice to cure or a suspension from participating or bidding for contracts, whet
Dade County or not.
All of the above information shall be attached to the executed affidavit and submitted to the Procurement Contracting Officer (PCO
overseeing this solicitation. The Vendor/Contractor attests to providing all of the above information, if applicable, to the PCO.
Federal Employer
Contract No.: Identification Number (FEIN):
Contract Title:
Printed Name of Affiant
Printed Title of Affiant
Name of Firm
F
Address of Firm State
Notary-Putlgtate of
Notary Public lnformation
County of
Subscribed and s*oriaffmmed) before me this day of,
by
Type of identification produced
Signature of Notary Public
Signature of Affiant
--
Date
--
Zip Code
20
He or she is personally known to me las produced identification
Print or Stamp of Notary Public Expiration Date
Serial Number
Notary Public Seal
5/3/2019 7:48 AM P. 15
Miami -Dade County
Solicitation RTQ-00918
Question and Answers for Solicitation #RTO%9-18
Installation, & Removal
Signs and Banners: Purchase,
Question 1
what is the budget/cost estimate? (Submitted: Jun 15, 2018 9:33:01 AM EDT)
Answer
- No budget/cost has not been identified (Answered: Jun 20, 2018 7:46:26 AM EDT)
5/3/2019 7:48 AM p, 16
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
Attachment C
NEON SIGN SOLUTIONS, INC. 16
ROADMAP
POOL NO. RTO.00918
SIGNS AND BANNERS. PURCHASE & INSTALLATION
Commodity ID: 968-81
Pool Term Dates: 05/01/2019 - 07/31/2029
All User -departments should include the link below when issuing all spot market quotes to ensure all firms listed on
pool are aware of the Terms and Conditions subject to an award:
hftp://www.miamidade.gov/procuremenUitb-terms-conditions.ao
I. Purpose: This pool provides a list of pre -qualified vendors forthe purchase, installation, and removal of signs and
banners as needed.
The following groups have been established:
Group 1: Purchase of Signs and Banners
Group 2: Purchase, Install, and/or Removal - Non -Electrical Signs and Banners
Group 3: Purchase, Install, and/or Removal - Electrical Signs and Banners
II. Pre -Qualified Vendors:
. , rm .Name . ....
` .. one o.:.
Company Rep.
E-Mail dress
Group,
AAA Flag & Banner
305-47 -7600
Retta Logan
RETTA anAAAF G.COM
1, 2, 3
Mfg. Co Inc.
Master Visuals Pro,
786-547-3785
Cesar Carrillo
cesar()mastervisualspro.com
1 & 2
LLC
Neon Sign Solutions,
305-885-7400
Jorge Idarraga
info@neonsiansolutions.com
1, 2, 3
Inc.
Paramount Service &
954-433-8001
Eric Ribe
eric@paramountsm.net
1, 2, 3
Mainten-ance, Corp.
Quadco Printing &
305-470 2229
Jorge Quadreny
forge anouadcoonline.com
1
Signs Inc.
Saul Signs Master, Inc.
305-266.8484
MannySagot
arturo(asaulsians.com
1, 2, 3
manuel()saulsigns.com
yaasniel ansaulsigns.com
iorge@saulsi nq s.com
Signalite, Inc.
305-406.3054
Jose Pacheco
jp(o)sionaliteinc.com
1, 2, 3
South Florida Lighting
305908-8000
Kurt Stange
kurt@miamichristmaslights.com
1
Team LLC dba Miami
Christmas Lights
Superior Office
305-323-7252
Edwin Gonzalez
agonzalez(a)superiorofiicesvcs,com
Services, LLC
System 2/90, Inc
800-777-4310
Cassie Groters
Casiearoters .290sians.com
1
dba 2 90 Sign Systems
Tigo dba Expose
954-935-5990
Marco Tiapago
marco eysi nq s.eom
1, 2, 3
Yourself
Total Connection, Inc.
305-651-3771
Joseph Orukotan
totalconnection06 6..bellsouth.net
1
Lark Label LLC
316-682-5275
Karl Miller
Karl@larklabel.com
1
Interpretive Graphics
801-942-5812
John Peters
John@interpretivegraphics.com
1
Signs & Systems
Daktronics Inc
407-784-
Kevin Cosgrove
Kevin.Cosgrove@daktronics.com
3
3792
III. Quote Procedures: The County will solicit spot market quotation from qualified vendors as -needed:
All pre -qualified vendors will be solicitedfor price and availability of projects as needed. All individual Information
to Quote (ITQ) should be reviewed for applicable measures prior to advertising. All quotations issued must be
registered with SBD at the following link: https://intra3.miamidade.gov/ISD/SBD/Login.aspx. This link officially 1
places your project on the Cone of Silence Report. Additionally the Office of the Commission Auditor (OCA) shall
be copied at oca()miamidade.aov when quote is issued.
IV. Small Business Enterprises (SBE) Measures (Group 3): All work orders shall be submitted to Small Business
Development for review and application of SBE-Con measures.
V. Applicable Ordinances for Quotations:
1) Local Certified Service— Disabled Veteran should be applied in accordance with Section 2-8.5.1 of the Miamk
Dade County Code, a Local Certified Service Disabled Veteran Business Enterprise (VBE) shall receive a bid
preference of 59/oof the price bid (for the purpose of evaluation ONLY). A VBEwho is also an SBE shall not
receive the veteran's preference and shall be limited to any applicable SBE preferences. At the time of bid
submission, the vendor must affirm in writing its compliance with the certification requirements of Section
295.187 of the Florida Status and submit this affirmation and a copy of the actual certification along with the
bid.
2) Local Preference hfp://library.municode.com/index.aspx?clientld=10620&stateld=9&stateName=Florida:
(Section 2-8.5; also applicable to Broward County vendors)
Additionally, a Locally -Headquartered Business shall mean a Local Business as defined above which has a
"principal place of business" in Miami -Dade County. "Principal place of business" means the nerve center or
the center of overall direction, control, and coordination of activities of the bidder. If the bidder has only one
business location, such business location shall be its principal place of business.
3) Cone of Silence http://IibraU.municode.comlindex.aspx?clientld=10620&stateld=9&stateName=Florida;
(Section 2-11.1)
4) UAP/Inspector'General Fees
http://Iibrary.municode.com/i ndex.aspx?cli entld=10620&stateld=9&stateNam e=Florida;
(Section 2-8.10)
5) CWP (Re: ITB Paragraph 2.2.2)
If the timefor completion of an ITQ issued under this contract is greater than 30 days, it is subject to a CWP
goal. As such, each ITQ greater than 30 days will be required to be presented to SBDfor the application of a
CWP goal.
VI. Event Loa:
vent No.,
Date
Event
Procurement Contracting
Officer
12
6/3/24
Daktronics inc Added to the pool
DRILL
11
5/30/24
Pool Extended to July 31, 2029
DRILL
10
3/26/24
Pool Extended to July 31, 2024
D.HILL
9
02/23/21
Updated contact information for Saul Signs Master, Inc.
Amelia M. Cordova -Jimenez
8
01 16/20
Added Lark Label
Lashonne Williams -Canty
7
01/16/20
Added Interpretive Graphics Signs & Systems
Lashonne Williams -Canty
6
0 08 20
AAA Flag & Banner 95-2921050 as been added to
Group 3 per vendor request via email.
Lashonne Williams -Canty
5
07/18/19
Added Signalite to the Pool.
Lashonne Williams -Canty
0611 19
Added Quadco, Printing to the Pool.
Lashonne Williams -Canty
3
06/10/19
Added Tigo dba Expose Yourself to the Pool.
Lashonne Williams -Canty
2
05/01/19
Published Contract Award Sheet for RTQ-00918.
Lashonne Williams -Canty
1
03/14/19
Added AAA Flag & Banner (95-2921050) to the Pool.
Lashonne Williams -Canty
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
Attachment D
NEON SIGN SOLUTIONS, INC. 17
CONTRACTOR ANTI. -BOYCOTT CERTIFICATION
Sit ATT
JPURSLVANT TO FLOWDA U. E 287.1351
o *61fof b
Print x4me Com-pany Na-ine
CeTtifl,ca that Algv�j g; 16P. Sowz��,V . domnbt:
. ......... -
Company Name
L. Part'l 40 4--bOY.c.0ft "of lskteh kiid
2; Ts ji9t dnthe Scraini�od Connp i les an.. -AiatBoyeath llinty. Ond
3. Is. nbt on -'the ScrUtinizod Compan io& with Ac.tiViti.- - ingtidanUstt-gn
e.S . , . d.
4, Is.. not 0h the ScrutinlZed Companies with Activities in the Iran Terrorism
.Sectors Vgt; and
5R
HU note in business onerations-4 Cuba or Syria:
In y ,
Title.
-..? 4 - ;2-.
Date
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
Attachment E
NEON SIGN SOLUTIONS, INC. 18
4 NNY IF�FS
CITY OF SUNNY ISLES BEACH
FLOR�V.�'
13FRFORMANCE REFERENCE SURVEY
Name of Company: NEON SIGNS
Project Title: MONUMENT SIGNS
The above referenced company has listed you as a business reference. Please provide reference information as
requested below. Your prompt attention is appreciated. Thank,you for your time and assistance.
Alexander Rando, Graphics Manager — Miami -Dade Public Library System
Using the drop -down menu to the right, please rate the following questions regarding services provided by the
firm listed above.
q. 2 3. 4 5 6
Exceptinn7r G;nnN Acceptable Poor Not Acceptable Not Applicabl
1.
Level of commitment the firm demonstrated when providing
Exceptional
services.
2.
Contractor's timeliness in mobilizing once permits have
Exceptional
been received.
3.
Firm's account representative's commitment to solving any
Exceptional
obstacles.
4.
Firm's ability to verbally/electronically communicate clearly
Exceptional
and effectively.
Exceptional
5.
Rate how contractor staffed and supervised the project.
Exceptional
6.
Maintained a clean, safe site.
Please type additional comments: We have worked with Neon Signs numerous times for over 10 years and
have been satisfied with their responsiveness, quality of work and professionalism.
1 of 1 225
CITY OF SUNNY ISI.E_:S BE-AC.I-,-i
P1;=P1ZnPMANr1= RFFFRFNCF St1RVEY
Name of Company: NEON SIGNS -
Project Title: MONUMENT SIGNS
The above referenced company has listed you as a business reference. Please provide reference information as
requested below. Your prompt attention is appreciated. Thank you for your time and assistance.
Name. and Titlei Martin Zidtowecki — Urban Landscape Designer - city of Fort Lauderdale
Using the drop -down menu to the right, please rate the following questions regarding services provided by the
firm listed above.
1 2. 3 4 S 6
Exceotiona! Good Acceptable Poor Not Acceptable Not Applicable .
1. Level of commitment the firm demonstrated when providing
t
services.
2. Contractor's timeliness in mobilizing once permits have
been received.
3. Firm's account representative's commitment to solving any
obstacles.
4. Fil m's ability to verbally/electronically communicate clearly
'-
and effectively.
5. Rate how contractor staffed and supervised the project.
1
I6. Maintained a clean, safe site.
~
Please type additional comments: Neon Signs do a great job for The City of Fort Lauderdale
1of1
City of Sunny Isles Beach 18070 Collins Avenue, Sunny Isles Beach, Florida 33160
(305) 947-0606 phone (305) 949-3113 Fax
Attachment F
NEON SIGN SOLUTIONS, INC. 19
Affidavit:of Compliance with Antj?-HqMr%'rrafrj;DkIh_q Laws
CRY Orl`.SWII�VISIOS 86cfi
, to
The Ondersloned,.On -behalf of the entity listed below ("Entity'), heribyattests, under permilty of
penury, OWS.
, jury, . as f6ft
I., Etml.ty- do" not:u4e-toetqI0.m for labor'.00'scirvi.0s qi§40fin6d- W.S.etti9n 787,00i. FId. Ada
Statut (S line.&.7.87.06-*(1 H:606 00taties._ Huftign troffwk:lq9),,
2:
Tho und6raigned %.AuJthbd'zbd.'t0 &Xlek . UW this.
Date:
IV k) 5 L 4 Ij $ o L VT 1'opff N me;
7tlo:
slwe&*
CO.UNTY OF tYjA.tWI_LbAll
9
The!. foreg-ping ihs(rurnem . t was k'knowl0ged Wbra.mp, b moarls-.0f) Sim
Y. hy il pre§efte 11
Le -m2*.l
th.15: 14 k 5 "
online. not-aKution, 0jjy of - by
for
to,
mly "C" VJI
me or who hss cad
Notary Public Signature: . . I -
State of'Fjorlda at Large,(Seal)
ek Nil A
SAW . MAUFTOR
Nopq hbllc -'St0e.*f Rod&
prbit Naml§.:
Iria t4b tifltwil �Ot;�Amn.
x 'per QE r
yR � ° FL�7 �� y�•
CfTk, QF SVN Alp
City of Sunny Isles Beach
18070 Collins Avenue
Sunny Isles Beach, Florida 33160
(305) 947-0606 City Hall
(305) 949-3113 Fax
MEMORANDUM
TO: Honorable Mayor and City Commissioners
VIA: Stan Morris, City Manager
FROM: Leah Einwalter, Media Manager
DATE: February 19, 2026
RE: Approval of a First Amendment to Agreement with Neon Signs for Monument
Signs
RECOMMENDATION:
Staff recommends approval of this resolution.
REASONS:
The proposed contract increase of $15,000 covers the cost of additional liability insurance required by
the Florida Department of Transportation (FDOT) for permittingthree monuments located within FDOT
Rights -of -Way, including the William Lehman Causeway monument and the north and south Collins
Avenue welcome signs. Therefore, the new contract total amount with this amendment is $965,000.
This First Amendment also extends the contract term by six months, through August 23, 2027, and
updates the payment schedule so that the initial 20% payment is divided evenly between the
design/installation phase (10%) and the permitting phase (10%).
FUNDING SOURCE:
Funds have been appropriated from account # 160-6-5730-464150-99016.
ATTACHMENTS:
Resolution
First Amendment - Neon Signs
Item Number: 9.J
716